import { RefObject } from 'react';
import { TrackingResult } from '../../components/Tracking';
declare type EventHandler<NativeEventType extends MouseEvent> = (result: TrackingResult<NativeEventType>) => void;
declare type PointerEventName = 'onPointerEnter' | 'onPointerDown' | 'onPointerMove' | 'onPointerUp' | 'onPointerLeave';
declare type ClickEventName = 'onClick' | 'onDoubleClick';
declare type WheelEventName = 'onWheel';
export declare type EventName = PointerEventName | ClickEventName | WheelEventName;
declare type PointerEventHandlers = {
    [key in PointerEventName]?: EventHandler<PointerEvent>;
};
declare type ClickEventHandlers = {
    [key in ClickEventName]?: EventHandler<MouseEvent>;
};
declare type WheelEventHandlers = {
    [key in WheelEventName]?: EventHandler<WheelEvent>;
};
export declare type EventsHandlers = PointerEventHandlers & ClickEventHandlers & WheelEventHandlers;
declare type EventMap = {
    [key in PointerEventName]: PointerEvent;
} & {
    [key in ClickEventName]: MouseEvent;
} & {
    [key in WheelEventName]: WheelEvent;
};
export interface PlotEventsUserActions {
    registerHandlers: (handlersRef: RefObject<EventsHandlers>) => void;
    unregisterHandlers: (handlersRef: RefObject<EventsHandlers>) => void;
}
export interface PlotEventsPlotActions {
    registerPlot: (plotId: string) => void;
    unregisterPlot: (plotId: string) => void;
    handleEvent: <T extends EventName>(plotId: string, eventName: T, eventData: TrackingResult<EventMap[T]>) => void;
}
export declare function usePlotEventsState(): {
    userActions: PlotEventsUserActions;
    plotActions: PlotEventsPlotActions;
};
export {};
