"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDrawPath = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const Polygon_1 = require("../components/Annotations/Polygon");
const Polyline_1 = require("../components/Annotations/Polyline");
const useStartMoveEnd_1 = require("./useStartMoveEnd");
function useDrawPath(options = {}) {
    const { horizontalAxisId = 'x', verticalAxisId = 'y', color = 'black', close = false, style, onDraw, onEnd, } = options;
    const [data, setData] = (0, react_1.useState)(null);
    (0, useStartMoveEnd_1.useStartMoveEnd)({
        ...options,
        onStart(result) {
            setData([result.clampedCoordinates]);
        },
        onMove(result) {
            setData((previousData) => {
                if (!previousData)
                    return null;
                const { clampedCoordinates } = result;
                let isDuplicated = true;
                for (const key in clampedCoordinates) {
                    if (previousData[previousData.length - 1][key] !==
                        clampedCoordinates[key]) {
                        isDuplicated = false;
                        break;
                    }
                }
                if (isDuplicated)
                    return previousData;
                return previousData.concat(clampedCoordinates);
            });
            onDraw === null || onDraw === void 0 ? void 0 : onDraw(points);
        },
        onEnd() {
            if (!data)
                return;
            setData(null);
            onEnd === null || onEnd === void 0 ? void 0 : onEnd(points);
        },
    });
    const points = (0, react_1.useMemo)(() => {
        if (!data)
            return [];
        return data.map((d) => ({
            x: d[horizontalAxisId],
            y: d[verticalAxisId],
        }));
    }, [data, horizontalAxisId, verticalAxisId]);
    return {
        annotations: data !== null ? (close ? ((0, jsx_runtime_1.jsx)(Polygon_1.Polygon, { color: color, style: style, points: points })) : ((0, jsx_runtime_1.jsx)(Polyline_1.Polyline, { color: color, style: style, points: points }))) : null,
    };
}
exports.useDrawPath = useDrawPath;
